@@ -758,6 +758,13 @@ Are you sure you want to continue?</translation>
         <translation>All processes</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation>Loading</translation>
+    </message>
+</context>
 <context>
     <name>Process.Signal</name>
     <message>
