@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="az" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
 <context>
     <name>App.About</name>
     <message>
@@ -771,6 +771,13 @@ Davam etmək istədiyinizə əminsiniz?</translation>
         <translation>Bütün proseslər</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -977,10 +984,12 @@ Davam etmək istədiyinizə əminsiniz?</translation>
     </message>
     <message>
         <source>OK</source>
+        <comment>button</comment>
         <translation>OLDU</translation>
     </message>
     <message>
         <source>Cancel</source>
+        <comment>button</comment>
         <translation>İmtina</translation>
     </message>
 </context>
@@ -1102,4 +1111,4 @@ Davam etmək istədiyinizə əminsiniz?</translation>
         <translation>Xidmətlər</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
