@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
 <context>
     <name>App.About</name>
     <message>
@@ -771,6 +771,13 @@ Es-tu sûr de vouloir continuer ?</translation>
         <translation>Tous les processus</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation>Chargement</translation>
+    </message>
+</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -977,10 +984,12 @@ Es-tu sûr de vouloir continuer ?</translation>
     </message>
     <message>
         <source>OK</source>
+        <comment>button</comment>
         <translation>OK</translation>
     </message>
     <message>
         <source>Cancel</source>
+        <comment>button</comment>
         <translation>Annuler</translation>
     </message>
 </context>
@@ -1102,4 +1111,4 @@ Es-tu sûr de vouloir continuer ?</translation>
         <translation>Services</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
