@@ -770,6 +770,13 @@ Are you sure you want to continue?</source>
         <translation>Semua proses</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -1101,4 +1108,4 @@ Are you sure you want to continue?</source>
         <translation type="unfinished"/>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
