@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
 <context>
     <name>App.About</name>
     <message>
@@ -506,13 +506,6 @@ Sicuro di voler terminarla?</translation>
         <translation>Termina</translation>
     </message>
 </context>
-<context>
-    <name>MainWindow</name>
-    <message>
-        <source>Settings</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>MemStatViewWidget</name>
     <message>
@@ -772,6 +765,13 @@ Sicuro di voler terminarla?</translation>
         <translation>Tutti i Processi</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation>Caricamento</translation>
+    </message>
+</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -978,10 +978,12 @@ Sicuro di voler terminarla?</translation>
     </message>
     <message>
         <source>OK</source>
+        <comment>button</comment>
         <translation>OK</translation>
     </message>
     <message>
         <source>Cancel</source>
+        <comment>button</comment>
         <translation>Annulla</translation>
     </message>
 </context>
@@ -1103,4 +1105,4 @@ Sicuro di voler terminarla?</translation>
         <translation>Servizi</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
